Package: markovchain
Type: Package
Title: Easy Handling Discrete Time Markov Chains
Version: 1.0.0
Authors@R: c(
    person("Giorgio Alfredo", "Spedicato", role = c("aut", "cre"),
      email = "spedicato_giorgio@yahoo.it",comment = c(ORCID = "0000-0002-0315-8888")),
    person("Tae", "Seung Kang", role = "aut"),
    person("Sai", "Bhargav Yalamanchi", role = "aut"),
    person("Mildenberger", "Thoralf", role = "ctb", comment = c(ORCID = "0000-0001-7242-1873")),
    person("Deepak", "Yadav", role = "aut"),
    person("Ignacio", "Cordón", role = "aut", comment = c(ORCID = "0000-0002-3152-0231")),
    person("Vandit", "Jain", role = "ctb"),
    person("Toni", "Giorgino", role="ctb", comment = c(ORCID = "0000-0001-6449-0596")),
    person("Richèl J.C.", "Bilderbeek", role = "ctb", comment = c(ORCID = "0000-0003-1107-7049")),
    person("Daniel", "Ebbert", email = "daniel@ebbert.nrw", role = "ctb", comment = c(ORCID = "0000-0003-3666-7205")),
    person("Shreyash", "Maheshwari", email = "coolshreysh1000@gmail.com", role = "ctb"),
    person("Reinhold", "Koch", role = "ctb")
  )
Maintainer: Giorgio Alfredo Spedicato <spedicato_giorgio@yahoo.it>
Description: Functions and S4 methods to create and manage discrete time Markov
    chains more easily. In addition functions to perform statistical (fitting
    and drawing random variates) and probabilistic (analysis of their structural
    proprieties) analysis are provided. See Spedicato (2017) <doi:10.32614/RJ-2017-036>.
    Some functions for continuous times Markov chains depend on the suggested ctmcd package.
License: MIT + file LICENSE
Depends: R (>= 4.4.0), Matrix (>= 1.5-0), methods
Imports: igraph, expm, stats4, parallel, Rcpp (>= 1.0.2), RcppParallel,
        utils, stats, grDevices
Suggests: knitr, testthat, diagram, DiagrammeR, ggplot2 (>= 3.4.0),
        msm, Rsolnp, rmarkdown, ctmcd, bookdown, rticles, MCMCpack,
        microbenchmark, quarto
Enhances: etm
VignetteBuilder: rmarkdown, knitr, bookdown, rticles, quarto
LinkingTo: Rcpp, RcppParallel, RcppArmadillo (>= 0.9.600.4.0)
SystemRequirements: GNU make, Quarto
LazyLoad: yes
ByteCompile: yes
Encoding: UTF-8
BugReports: https://github.com/spedygiorgio/markovchain/issues
URL: https://github.com/spedygiorgio/markovchain/
NeedsCompilation: yes
Packaged: 2026-08-24 16:53:43 UTC; Utente
Author: Giorgio Alfredo Spedicato [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-0315-8888>),
  Tae Seung Kang [aut],
  Sai Bhargav Yalamanchi [aut],
  Mildenberger Thoralf [ctb] (ORCID:
    <https://orcid.org/0000-0001-7242-1873>),
  Deepak Yadav [aut],
  Ignacio Cordón [aut] (ORCID: <https://orcid.org/0000-0002-3152-0231>),
  Vandit Jain [ctb],
  Toni Giorgino [ctb] (ORCID: <https://orcid.org/0000-0001-6449-0596>),
  Richèl J.C. Bilderbeek [ctb] (ORCID:
    <https://orcid.org/0000-0003-1107-7049>),
  Daniel Ebbert [ctb] (ORCID: <https://orcid.org/0000-0003-3666-7205>),
  Shreyash Maheshwari [ctb],
  Reinhold Koch [ctb]
Config/roxygen2/version: 8.1.0
Repository: CRAN
Date/Publication: 2026-08-25 05:20:22 UTC
Built: R 4.6.1; aarch64-apple-darwin23; 2026-08-25 08:17:12 UTC; unix
Archs: markovchain.so.dSYM
