# Generated by roxygen2: do not edit by hand

export("name<-")
export(.markovchainFitRcpp)
export(ExpectedTime)
export(absorptionProbabilities)
export(assessOrder)
export(assessStationarity)
export(committorAB)
export(createSequenceMatrix)
export(ctmcFit)
export(expectedRewards)
export(expectedRewardsBeforeHittingA)
export(firstPassage)
export(firstPassageMultiple)
export(fitHighOrderMultivarMC)
export(fitHigherOrder)
export(freq2Generator)
export(generatorToTransitionMatrix)
export(hommc)
export(impreciseProbabilityatT)
export(inferHyperparam)
export(is.CTMCirreducible)
export(is.TimeReversible)
export(is.stochasticallyMonotone)
export(markovchainFit)
export(markovchainListFit)
export(markovchainSequence)
export(meanAbsorptionTime)
export(meanFirstPassageTime)
export(meanRecurrenceTime)
export(multinomialConfidenceIntervals)
export(name)
export(noofVisitsDist)
export(period)
export(predictHommc)
export(predictiveDistribution)
export(priorDistribution)
export(probabilityatT)
export(rctmc)
export(rmarkovchain)
export(seq2freqProb)
export(seq2matHigh)
export(states)
export(transition2Generator)
export(verifyEmpiricalToTheoretical)
export(verifyHomogeneity)
export(verifyMarkovProperty)
exportClasses(HigherOrderMarkovChain)
exportClasses(ctmc)
exportClasses(hommc)
exportClasses(markovchain)
exportClasses(markovchainList)
exportMethods("!=")
exportMethods("*")
exportMethods("==")
exportMethods("[")
exportMethods("[[")
exportMethods("^")
exportMethods(absorbingStates)
exportMethods(canonicForm)
exportMethods(coerce)
exportMethods(communicatingClasses)
exportMethods(conditionalDistribution)
exportMethods(dim)
exportMethods(hittingProbabilities)
exportMethods(is.accessible)
exportMethods(is.irreducible)
exportMethods(is.regular)
exportMethods(meanNumVisits)
exportMethods(plot)
exportMethods(predict)
exportMethods(print)
exportMethods(recurrentClasses)
exportMethods(recurrentStates)
exportMethods(show)
exportMethods(steadyStates)
exportMethods(summary)
exportMethods(t)
exportMethods(transientClasses)
exportMethods(transientStates)
exportMethods(transitionProbability)
import(Matrix)
import(igraph)
import(methods)
import(parallel)
importFrom(Rcpp,evalCpp)
importFrom(RcppParallel,RcppParallelLibs)
importFrom(expm,
  "%^%",
  logm
)
importFrom(grDevices,colors)
importFrom(stats,
  aggregate,
  chisq.test,
  pchisq,
  predict,
  rexp,
  rmultinom,
  sd
)
importFrom(stats4,
  plot,
  summary
)
importFrom(utils,packageDescription)
useDynLib(markovchain, .registration = TRUE)
