# markovchain

R package providing classes, methods and function for easily handling Discrete Time Markov Chains (DTMC), performing probabilistic analysis and fitting.

## Install the current release from CRAN:

```r
install.packages('markovchain')
```

## Install the development version from GitHub:

```r
devtools::install_github('spedygiorgio/markovchain')
```

![alt tag](https://travis-ci.org/spedygiorgio/markovchain.svg?branch=master)
[![Downloads](http://cranlogs.r-pkg.org/badges/markovchain)](https://cran.r-project.org/package=markovchain)
[![CRAN_Status_Badge](https://img.shields.io/cran/v/markovchain?label=CRAN)](https://CRAN.R-project.org/package=markovchain)
[![Research software impact](http://depsy.org/api/package/cran/markovchain/badge.svg)](http://depsy.org/package/r/markovchain)

<!-- badges: start -->
[![R-CMD-check](https://github.com/spedygiorgio/markovchain/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/spedygiorgio/markovchain/actions/workflows/R-CMD-check.yaml)
[![Codecov test coverage](https://codecov.io/gh/spedygiorgio/markovchain/graph/badge.svg)](https://app.codecov.io/gh/spedygiorgio/markovchain)
<!-- badges: end -->

## License and citation

The package is distributed under the [MIT License](LICENSE), which permits commercial and non-commercial use, modification, distribution, and private use, provided the copyright notice and permission notice are retained in copies or substantial portions of the software.

If you use `markovchain` in published work, please cite the package as follows:

```r
citation("markovchain")
```

or in bibliography form:

```text
Spedicato, G. A. (2017). Discrete Time Markov Chains with R. The R Journal, 9(2), 84-104.
```

This citation is also provided in [inst/CITATION](inst/CITATION).
