% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/matlab_package_functions.R
\name{ones}
\alias{ones}
\title{Returns an Identity matrix}
\usage{
ones(n)
}
\arguments{
\item{n}{size of the matrix}
}
\value{
a identity matrix
}
\description{
Returns an Identity matrix
}
