% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/matlab_package_functions.R
\name{zeros}
\alias{zeros}
\title{Matrix to create zeros}
\usage{
zeros(n)
}
\arguments{
\item{n}{size of the matrix}
}
\value{
a square matrix of zeros
}
\description{
Matrix to create zeros
}
